@@ -23,7 +23,7 @@ from .error import (
     ApiError,
     PowerwallUnreachableError,
 )
-from .helpers import convert_to_kwh
+from .helpers import convert_to_kw
 from .responses import (
     CustomerRegistrationResponse,
     ListPowerwallsResponse,
@@ -38,7 +38,7 @@ from .responses import (
     PowerwallsStatusResponse,
 )
 
-VERSION = "0.2.0"
+VERSION = "0.2.2"
 
 
 class Powerwall(object):
